==> aroundme_0_7_0.zip: aroundme_0_7_0/aroundme/components/core/language/1/barnraiser_01/people.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------



// HEADERS
$lang['hdr_search_intro'] = 					"enabling your search";
$lang['hdr_search_results'] = 					"search results";
$lang['hdr_search'] = 							"search";


// ERRORS
$lang['error']['metadata_empty'] = 				"You have not entered any metadata.";
$lang['error']['empty_search'] = 				"You have not entered any search criteria.";


// SUBMIT 
$lang['sub_update_search'] = 					"update search preferences";
$lang['sub_search'] = 							"search";

// HREF
$lang['href_advanced_search'] = 				"advanced";
$lang['href_edit_metadata'] = 					"edit my metadata";


// TEXTS
$lang['txt_metadata'] =							"search words";
$lang['txt_search_text'] =						"search text";
$lang['txt_metadata_intro'] =					"Type in words separated by a comma that describe you. This will be used for other members when searching for people.";
$lang['txt_search_intro'] =						"You can search on people, their location and their search criteria (called 'metadata'). To do this you must first allow others to search on you. By pressing 'update search preferences' you agree to allow other people to search on your search criteria. If at a later date you wish to change this simply go into your account and uncheck your search preferences.";
$lang['txt_searchable_users'] =					"There are currently SYS_KEYWORD_COUNT people who have their preferences set to allow you to search on them.";
$lang['txt_my_metadata'] =						"my meta data";
$lang['txt_network_metadata'] =					"meta data in my immediate network";
$lang['txt_network_tags'] =						"network tags";
$lang['txt_location'] = 						"location";
$lang['txt_identity_search'] = 					"identity search";
$lang['txt_none'] = 							"none";
$lang['txt_sort'] = 							"sort by";

?>

==> aroundme_0_7_6.zip: aroundme_0_7_6/aroundme/components/core/language/1/barnraiser_01/people.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once($language_path . 'inc/me_common.inc.php');

// HEADERS
$lang['hdr_search_intro'] = 					"enabling your search";
$lang['hdr_search_results'] = 					"search results";
$lang['hdr_search'] = 							"search";


// ERRORS
$lang['error']['metadata_empty'] = 				"You have not entered any metadata.";
$lang['error']['empty_search'] = 				"You have not entered any search criteria.";


// SUBMIT 
//$lang['sub_update_search'] = 					"update search preferences";
$lang['sub_search'] = 							"search";

// HREF
$lang['href_advanced_search'] = 				"advanced";
//$lang['href_edit_metadata'] = 					"edit my metadata";


// TEXTS
$lang['txt_metadata'] =							"search words";
$lang['txt_search_text'] =						"search text";
//$lang['txt_metadata_intro'] =					"Type in words separated by a comma that describe you. This will be used for other members when searching for people.";
$lang['txt_search_intro'] =						"You can search on people, their location and their identity search criteria (called 'metadata'). To do this you must first allow others to search on one of your identities. Simply go into your identities page, edit one of your identities and check the 'allow people to search on this identity card' option.";
$lang['txt_searchable_users'] =					"There are currently SYS_KEYWORD_COUNT people who have their preferences set to allow you to search on them.";
$lang['txt_my_metadata'] =						"my meta data";
$lang['txt_user_metadata'] =					"general meta data";
$lang['txt_network_tags'] =						"network tags";
$lang['txt_location'] = 						"location";
$lang['txt_identity_search'] = 					"identity search";
$lang['txt_none'] = 							"none";
$lang['txt_sort'] = 							"sort by";

?>
